"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rest = require("node-rest-client");
/** This bolt sends POST request to specified url (fixed or provided inside data)
 * and forwards the request.
 */
class PostBolt {
    constructor() {
        this.onEmit = null;
        this.fixed_url = null;
    }
    init(name, config, context, callback) {
        this.onEmit = config.onEmit;
        this.fixed_url = config.url;
        this.client = new rest.Client();
        callback();
    }
    heartbeat() {
        // no-op
    }
    shutdown(callback) {
        callback();
    }
    receive(data, stream_id, callback) {
        let url = this.fixed_url;
        const args = { data, headers: { "Content-Type": "application/json" } };
        if (!this.fixed_url) {
            url = data.url;
            args.data = data.body;
        }
        const req = this.client.post(url, args, (new_data, response) => {
            this.onEmit({ body: new_data }, null, callback);
        });
        req.on("error", err => {
            callback(err);
        });
    }
}
exports.PostBolt = PostBolt;
//# sourceMappingURL=post_bolt.js.map